==> libwacom-0.6.tar.bz2: libwacom-0.6/doc/html/search/enumvalues_77.js <==
var searchData=
[
  ['wacom_5fbutton_5fdirection',['WACOM_BUTTON_DIRECTION',['../libwacom_8h.html#a7349dfd03aece0522b2133c7fbe9021da2e822ddd1d44b7095391931d27042b27',1,'libwacom.h']]],
  ['wacom_5fbutton_5fmodeswitch',['WACOM_BUTTON_MODESWITCH',['../libwacom_8h.html#a7349dfd03aece0522b2133c7fbe9021dab8d69722b1e8e6eb1a2ea32ca5635829',1,'libwacom.h']]],
  ['wacom_5fbutton_5fnone',['WACOM_BUTTON_NONE',['../libwacom_8h.html#a7349dfd03aece0522b2133c7fbe9021da1fa9422e0046bd493c7461d4d8bd1564',1,'libwacom.h']]],
  ['wacom_5fbutton_5foled',['WACOM_BUTTON_OLED',['../libwacom_8h.html#a7349dfd03aece0522b2133c7fbe9021dac0c92f8d7d64d4a98fab32726a71a3ba',1,'libwacom.h']]],
  ['wacom_5fbutton_5fposition_5fbottom',['WACOM_BUTTON_POSITION_BOTTOM',['../libwacom_8h.html#a7349dfd03aece0522b2133c7fbe9021da13ab5a3faf0938dc73130832d9793249',1,'libwacom.h']]],
  ['wacom_5fbutton_5fposition_5fleft',['WACOM_BUTTON_POSITION_LEFT',['../libwacom_8h.html#a7349dfd03aece0522b2133c7fbe9021da9c69feb2ff272365699e6bf26ac35f61',1,'libwacom.h']]],
  ['wacom_5fbutton_5fposition_5fright',['WACOM_BUTTON_POSITION_RIGHT',['../libwacom_8h.html#a7349dfd03aece0522b2133c7fbe9021dab0507a10fd15b6eac4a53f8bfe1bdb47',1,'libwacom.h']]],
  ['wacom_5fbutton_5fposition_5ftop',['WACOM_BUTTON_POSITION_TOP',['../libwacom_8h.html#a7349dfd03aece0522b2133c7fbe9021da6244641c9541bb30a672893de46a5463',1,'libwacom.h']]],
  ['wacom_5fbutton_5fring2_5fmodeswitch',['WACOM_BUTTON_RING2_MODESWITCH',['../libwacom_8h.html#a7349dfd03aece0522b2133c7fbe9021da74d3cc0d326a1b5a5b856824d4d0f949',1,'libwacom.h']]],
  ['wacom_5fbutton_5fring_5fmodeswitch',['WACOM_BUTTON_RING_MODESWITCH',['../libwacom_8h.html#a7349dfd03aece0522b2133c7fbe9021dade285ee1f37744428a4f15bd83a7229b',1,'libwacom.h']]],
  ['wacom_5fbutton_5frings_5fmodeswitch',['WACOM_BUTTON_RINGS_MODESWITCH',['../libwacom_8h.html#a7349dfd03aece0522b2133c7fbe9021da239d75d58b0ea0614ac4afcc1f527f5d',1,'libwacom.h']]],
  ['wacom_5fbutton_5ftouchstrip2_5fmodeswitch',['WACOM_BUTTON_TOUCHSTRIP2_MODESWITCH',['../libwacom_8h.html#a7349dfd03aece0522b2133c7fbe9021da41c77218ff1a41cd32bd2bd5e179799b',1,'libwacom.h']]],
  ['wacom_5fbutton_5ftouchstrip_5fmodeswitch',['WACOM_BUTTON_TOUCHSTRIP_MODESWITCH',['../libwacom_8h.html#a7349dfd03aece0522b2133c7fbe9021dac1c9baa6fe67ceaab2db3aea48a52b5c',1,'libwacom.h']]],
  ['wacom_5fbutton_5ftouchstrips_5fmodeswitch',['WACOM_BUTTON_TOUCHSTRIPS_MODESWITCH',['../libwacom_8h.html#a7349dfd03aece0522b2133c7fbe9021da168d068d5d6de79ae30485bf9185bee9',1,'libwacom.h']]],
  ['wbustype_5fbluetooth',['WBUSTYPE_BLUETOOTH',['../libwacom_8h.html#ac2fa165c0691b65d55f46eabdd02c96ead9a398b5e4e63bd10e82e93a7298d897',1,'libwacom.h']]],
  ['wbustype_5fserial',['WBUSTYPE_SERIAL',['../libwacom_8h.html#ac2fa165c0691b65d55f46eabdd02c96eab688bccdc01b1568549795024ef0a9cd',1,'libwacom.h']]],
  ['wbustype_5funknown',['WBUSTYPE_UNKNOWN',['../libwacom_8h.html#ac2fa165c0691b65d55f46eabdd02c96eaaafbf19c1afe7e030435cc93dcf5e80f',1,'libwacom.h']]],
  ['wbustype_5fusb',['WBUSTYPE_USB',['../libwacom_8h.html#ac2fa165c0691b65d55f46eabdd02c96ea975598b827928f5665473790b9ef378f',1,'libwacom.h']]],
  ['wclass_5fbamboo',['WCLASS_BAMBOO',['../libwacom_8h.html#abe5d90234cce1b8ad62be2676a1d56e5ab5acb23ad0abee32f973c3e69fa58d48',1,'libwacom.h']]],
  ['wclass_5fcintiq',['WCLASS_CINTIQ',['../libwacom_8h.html#abe5d90234cce1b8ad62be2676a1d56e5a274e9c4cb424cd0e7e402335fd54d075',1,'libwacom.h']]],
  ['wclass_5fgraphire',['WCLASS_GRAPHIRE',['../libwacom_8h.html#abe5d90234cce1b8ad62be2676a1d56e5a37f1361e6d664c15fcf8174bbf41e032',1,'libwacom.h']]],
  ['wclass_5fintuos',['WCLASS_INTUOS',['../libwacom_8h.html#abe5d90234cce1b8ad62be2676a1d56e5a46e717d944a2567d8215fec1dbf94319',1,'libwacom.h']]],
  ['wclass_5fintuos2',['WCLASS_INTUOS2',['../libwacom_8h.html#abe5d90234cce1b8ad62be2676a1d56e5a2fcc611a388c4702544b4ad15ceed3a3',1,'libwacom.h']]],
  ['wclass_5fintuos3',['WCLASS_INTUOS3',['../libwacom_8h.html#abe5d90234cce1b8ad62be2676a1d56e5a109704876fb26b24b30ca9c78410b185',1,'libwacom.h']]],
  ['wclass_5fintuos4',['WCLASS_INTUOS4',['../libwacom_8h.html#abe5d90234cce1b8ad62be2676a1d56e5a9e490c842cfb39996831d091f758bd87',1,'libwacom.h']]],
  ['wclass_5fintuos5',['WCLASS_INTUOS5',['../libwacom_8h.html#abe5d90234cce1b8ad62be2676a1d56e5a464aa81ee559e12fd8fd8b5a47039cf1',1,'libwacom.h']]],
  ['wclass_5fisdv4',['WCLASS_ISDV4',['../libwacom_8h.html#abe5d90234cce1b8ad62be2676a1d56e5a9b9531af5e603a5c3a60c3daa301b9c7',1,'libwacom.h']]],
  ['wclass_5fpen_5fdisplays',['WCLASS_PEN_DISPLAYS',['../libwacom_8h.html#abe5d90234cce1b8ad62be2676a1d56e5a538110afcafb8e6d8987aa3b96d4103f',1,'libwacom.h']]],
  ['wclass_5funknown',['WCLASS_UNKNOWN',['../libwacom_8h.html#abe5d90234cce1b8ad62be2676a1d56e5a2aa39060933230cc40f430926a491905',1,'libwacom.h']]],
  ['wcompare_5fmatches',['WCOMPARE_MATCHES',['../libwacom_8h.html#aa3dccc523f834020bc0aea0f6621ef8fa1c64076e17a6b14fec9d67d50324fd26',1,'libwacom.h']]],
  ['wcompare_5fnormal',['WCOMPARE_NORMAL',['../libwacom_8h.html#aa3dccc523f834020bc0aea0f6621ef8fa1c12e4cb051cf4c35575bf43686edfce',1,'libwacom.h']]],
  ['werror_5fbad_5faccess',['WERROR_BAD_ACCESS',['../libwacom_8h.html#ac3d9ee175999d6b22cee82aae8f829deac75d78a6e9b7623893cf1df578d45621',1,'libwacom.h']]],
  ['werror_5fbad_5falloc',['WERROR_BAD_ALLOC',['../libwacom_8h.html#ac3d9ee175999d6b22cee82aae8f829dea3d78c00cc843776081a65ee1a5aa422c',1,'libwacom.h']]],
  ['werror_5finvalid_5fdb',['WERROR_INVALID_DB',['../libwacom_8h.html#ac3d9ee175999d6b22cee82aae8f829dea6a71f4220569aa8f02a5e1aff0849d3a',1,'libwacom.h']]],
  ['werror_5finvalid_5fpath',['WERROR_INVALID_PATH',['../libwacom_8h.html#ac3d9ee175999d6b22cee82aae8f829deafcbd87b0d3a6cd34d62fb273f0c98948',1,'libwacom.h']]],
  ['werror_5fnone',['WERROR_NONE',['../libwacom_8h.html#ac3d9ee175999d6b22cee82aae8f829dea07a92a6da7f7a6f6da02fac013e2f1d8',1,'libwacom.h']]],
  ['werror_5funknown_5fmodel',['WERROR_UNKNOWN_MODEL',['../libwacom_8h.html#ac3d9ee175999d6b22cee82aae8f829dea5b60ef039615d8c012fa011025177a91',1,'libwacom.h']]],
  ['wfallback_5fgeneric',['WFALLBACK_GENERIC',['../libwacom_8h.html#ac345850b5a595ab24cf120e2a89005d7a1e9f569873e7c61e7998fd99967a11e0',1,'libwacom.h']]],
  ['wfallback_5fnone',['WFALLBACK_NONE',['../libwacom_8h.html#ac345850b5a595ab24cf120e2a89005d7a5b09a66d5f5ae50891993d7cf5d6cd45',1,'libwacom.h']]],
  ['wstylus_5fairbrush',['WSTYLUS_AIRBRUSH',['../libwacom_8h.html#a6f96ee71140aee8ac56c80fb8353c3f6a2b2b5a21b1b32b4655bdd7a2523d1d5f',1,'libwacom.h']]],
  ['wstylus_5fclassic',['WSTYLUS_CLASSIC',['../libwacom_8h.html#a6f96ee71140aee8ac56c80fb8353c3f6a5e7fa448c848fbf5305292d2f37ded4f',1,'libwacom.h']]],
  ['wstylus_5fgeneral',['WSTYLUS_GENERAL',['../libwacom_8h.html#a6f96ee71140aee8ac56c80fb8353c3f6a83751cf86d3119e7ee5575286871da72',1,'libwacom.h']]],
  ['wstylus_5finking',['WSTYLUS_INKING',['../libwacom_8h.html#a6f96ee71140aee8ac56c80fb8353c3f6a69f019a42c8f058f383e9570d07129dc',1,'libwacom.h']]],
  ['wstylus_5fmarker',['WSTYLUS_MARKER',['../libwacom_8h.html#a6f96ee71140aee8ac56c80fb8353c3f6a0b434fba67e0e26359ee96bdbe5e5171',1,'libwacom.h']]],
  ['wstylus_5fpuck',['WSTYLUS_PUCK',['../libwacom_8h.html#a6f96ee71140aee8ac56c80fb8353c3f6aab5835d0572f445f5aaf555315a074d7',1,'libwacom.h']]],
  ['wstylus_5fstroke',['WSTYLUS_STROKE',['../libwacom_8h.html#a6f96ee71140aee8ac56c80fb8353c3f6a99c68bfb134bbbb0a7aee9aab11ebf35',1,'libwacom.h']]],
  ['wstylus_5funknown',['WSTYLUS_UNKNOWN',['../libwacom_8h.html#a6f96ee71140aee8ac56c80fb8353c3f6ab0ce0a738eb1d022736559e59a7b64d6',1,'libwacom.h']]]
];

==> libwacom_0.8.orig.tar.bz2: libwacom-0.8/doc/html/search/enumvalues_77.js <==
var searchData=
[
  ['wacom_5fbutton_5fdirection',['WACOM_BUTTON_DIRECTION',['../libwacom_8h.html#a7349dfd03aece0522b2133c7fbe9021da2e822ddd1d44b7095391931d27042b27',1,'libwacom.h']]],
  ['wacom_5fbutton_5fmodeswitch',['WACOM_BUTTON_MODESWITCH',['../libwacom_8h.html#a7349dfd03aece0522b2133c7fbe9021dab8d69722b1e8e6eb1a2ea32ca5635829',1,'libwacom.h']]],
  ['wacom_5fbutton_5fnone',['WACOM_BUTTON_NONE',['../libwacom_8h.html#a7349dfd03aece0522b2133c7fbe9021da1fa9422e0046bd493c7461d4d8bd1564',1,'libwacom.h']]],
  ['wacom_5fbutton_5foled',['WACOM_BUTTON_OLED',['../libwacom_8h.html#a7349dfd03aece0522b2133c7fbe9021dac0c92f8d7d64d4a98fab32726a71a3ba',1,'libwacom.h']]],
  ['wacom_5fbutton_5fposition_5fbottom',['WACOM_BUTTON_POSITION_BOTTOM',['../libwacom_8h.html#a7349dfd03aece0522b2133c7fbe9021da13ab5a3faf0938dc73130832d9793249',1,'libwacom.h']]],
  ['wacom_5fbutton_5fposition_5fleft',['WACOM_BUTTON_POSITION_LEFT',['../libwacom_8h.html#a7349dfd03aece0522b2133c7fbe9021da9c69feb2ff272365699e6bf26ac35f61',1,'libwacom.h']]],
  ['wacom_5fbutton_5fposition_5fright',['WACOM_BUTTON_POSITION_RIGHT',['../libwacom_8h.html#a7349dfd03aece0522b2133c7fbe9021dab0507a10fd15b6eac4a53f8bfe1bdb47',1,'libwacom.h']]],
  ['wacom_5fbutton_5fposition_5ftop',['WACOM_BUTTON_POSITION_TOP',['../libwacom_8h.html#a7349dfd03aece0522b2133c7fbe9021da6244641c9541bb30a672893de46a5463',1,'libwacom.h']]],
  ['wacom_5fbutton_5fring2_5fmodeswitch',['WACOM_BUTTON_RING2_MODESWITCH',['../libwacom_8h.html#a7349dfd03aece0522b2133c7fbe9021da74d3cc0d326a1b5a5b856824d4d0f949',1,'libwacom.h']]],
  ['wacom_5fbutton_5fring_5fmodeswitch',['WACOM_BUTTON_RING_MODESWITCH',['../libwacom_8h.html#a7349dfd03aece0522b2133c7fbe9021dade285ee1f37744428a4f15bd83a7229b',1,'libwacom.h']]],
  ['wacom_5fbutton_5frings_5fmodeswitch',['WACOM_BUTTON_RINGS_MODESWITCH',['../libwacom_8h.html#a7349dfd03aece0522b2133c7fbe9021da239d75d58b0ea0614ac4afcc1f527f5d',1,'libwacom.h']]],
  ['wacom_5fbutton_5ftouchstrip2_5fmodeswitch',['WACOM_BUTTON_TOUCHSTRIP2_MODESWITCH',['../libwacom_8h.html#a7349dfd03aece0522b2133c7fbe9021da41c77218ff1a41cd32bd2bd5e179799b',1,'libwacom.h']]],
  ['wacom_5fbutton_5ftouchstrip_5fmodeswitch',['WACOM_BUTTON_TOUCHSTRIP_MODESWITCH',['../libwacom_8h.html#a7349dfd03aece0522b2133c7fbe9021dac1c9baa6fe67ceaab2db3aea48a52b5c',1,'libwacom.h']]],
  ['wacom_5fbutton_5ftouchstrips_5fmodeswitch',['WACOM_BUTTON_TOUCHSTRIPS_MODESWITCH',['../libwacom_8h.html#a7349dfd03aece0522b2133c7fbe9021da168d068d5d6de79ae30485bf9185bee9',1,'libwacom.h']]],
  ['wacom_5fdevice_5fintegrated_5fdisplay',['WACOM_DEVICE_INTEGRATED_DISPLAY',['../libwacom_8h.html#a89b8a336b7d1d0d37659db8fe976323da957fb212fda27c9a006d6121266b04f1',1,'libwacom.h']]],
  ['wacom_5fdevice_5fintegrated_5fnone',['WACOM_DEVICE_INTEGRATED_NONE',['../libwacom_8h.html#a89b8a336b7d1d0d37659db8fe976323da9b8f1d3d89a25bf5628789a8822800f1',1,'libwacom.h']]],
  ['wacom_5fdevice_5fintegrated_5fsystem',['WACOM_DEVICE_INTEGRATED_SYSTEM',['../libwacom_8h.html#a89b8a336b7d1d0d37659db8fe976323dab5f6f55d44f18b26f0569676e1344857',1,'libwacom.h']]],
  ['wacom_5fstatus_5fled_5fring',['WACOM_STATUS_LED_RING',['../libwacom_8h.html#a18a534584fbfeb1254107b30246bcfd6a5ff0f7a54421536958f76f1fa13b32a0',1,'libwacom.h']]],
  ['wacom_5fstatus_5fled_5fring2',['WACOM_STATUS_LED_RING2',['../libwacom_8h.html#a18a534584fbfeb1254107b30246bcfd6a7764f598cd2e21bea2c2162503dda5f6',1,'libwacom.h']]],
  ['wacom_5fstatus_5fled_5ftouchstrip',['WACOM_STATUS_LED_TOUCHSTRIP',['../libwacom_8h.html#a18a534584fbfeb1254107b30246bcfd6a89bac8fcc84c8868918cb2bbe1ae683a',1,'libwacom.h']]],
  ['wacom_5fstatus_5fled_5ftouchstrip2',['WACOM_STATUS_LED_TOUCHSTRIP2',['../libwacom_8h.html#a18a534584fbfeb1254107b30246bcfd6a2fbb178e496555ec0591548dec2e141c',1,'libwacom.h']]],
  ['wacom_5fstatus_5fled_5funavailable',['WACOM_STATUS_LED_UNAVAILABLE',['../libwacom_8h.html#a18a534584fbfeb1254107b30246bcfd6a3bd225390cbe0e364beb86269d746393',1,'libwacom.h']]],
  ['wbustype_5fbluetooth',['WBUSTYPE_BLUETOOTH',['../libwacom_8h.html#ac2fa165c0691b65d55f46eabdd02c96ead9a398b5e4e63bd10e82e93a7298d897',1,'libwacom.h']]],
  ['wbustype_5fserial',['WBUSTYPE_SERIAL',['../libwacom_8h.html#ac2fa165c0691b65d55f46eabdd02c96eab688bccdc01b1568549795024ef0a9cd',1,'libwacom.h']]],
  ['wbustype_5funknown',['WBUSTYPE_UNKNOWN',['../libwacom_8h.html#ac2fa165c0691b65d55f46eabdd02c96eaaafbf19c1afe7e030435cc93dcf5e80f',1,'libwacom.h']]],
  ['wbustype_5fusb',['WBUSTYPE_USB',['../libwacom_8h.html#ac2fa165c0691b65d55f46eabdd02c96ea975598b827928f5665473790b9ef378f',1,'libwacom.h']]],
  ['wclass_5fbamboo',['WCLASS_BAMBOO',['../libwacom_8h.html#abe5d90234cce1b8ad62be2676a1d56e5ab5acb23ad0abee32f973c3e69fa58d48',1,'libwacom.h']]],
  ['wclass_5fcintiq',['WCLASS_CINTIQ',['../libwacom_8h.html#abe5d90234cce1b8ad62be2676a1d56e5a274e9c4cb424cd0e7e402335fd54d075',1,'libwacom.h']]],
  ['wclass_5fgraphire',['WCLASS_GRAPHIRE',['../libwacom_8h.html#abe5d90234cce1b8ad62be2676a1d56e5a37f1361e6d664c15fcf8174bbf41e032',1,'libwacom.h']]],
  ['wclass_5fintuos',['WCLASS_INTUOS',['../libwacom_8h.html#abe5d90234cce1b8ad62be2676a1d56e5a46e717d944a2567d8215fec1dbf94319',1,'libwacom.h']]],
  ['wclass_5fintuos2',['WCLASS_INTUOS2',['../libwacom_8h.html#abe5d90234cce1b8ad62be2676a1d56e5a2fcc611a388c4702544b4ad15ceed3a3',1,'libwacom.h']]],
  ['wclass_5fintuos3',['WCLASS_INTUOS3',['../libwacom_8h.html#abe5d90234cce1b8ad62be2676a1d56e5a109704876fb26b24b30ca9c78410b185',1,'libwacom.h']]],
  ['wclass_5fintuos4',['WCLASS_INTUOS4',['../libwacom_8h.html#abe5d90234cce1b8ad62be2676a1d56e5a9e490c842cfb39996831d091f758bd87',1,'libwacom.h']]],
  ['wclass_5fintuos5',['WCLASS_INTUOS5',['../libwacom_8h.html#abe5d90234cce1b8ad62be2676a1d56e5a464aa81ee559e12fd8fd8b5a47039cf1',1,'libwacom.h']]],
  ['wclass_5fisdv4',['WCLASS_ISDV4',['../libwacom_8h.html#abe5d90234cce1b8ad62be2676a1d56e5a9b9531af5e603a5c3a60c3daa301b9c7',1,'libwacom.h']]],
  ['wclass_5fpen_5fdisplays',['WCLASS_PEN_DISPLAYS',['../libwacom_8h.html#abe5d90234cce1b8ad62be2676a1d56e5a538110afcafb8e6d8987aa3b96d4103f',1,'libwacom.h']]],
  ['wclass_5funknown',['WCLASS_UNKNOWN',['../libwacom_8h.html#abe5d90234cce1b8ad62be2676a1d56e5a2aa39060933230cc40f430926a491905',1,'libwacom.h']]],
  ['wcompare_5fmatches',['WCOMPARE_MATCHES',['../libwacom_8h.html#aa3dccc523f834020bc0aea0f6621ef8fa1c64076e17a6b14fec9d67d50324fd26',1,'libwacom.h']]],
  ['wcompare_5fnormal',['WCOMPARE_NORMAL',['../libwacom_8h.html#aa3dccc523f834020bc0aea0f6621ef8fa1c12e4cb051cf4c35575bf43686edfce',1,'libwacom.h']]],
  ['werror_5fbad_5faccess',['WERROR_BAD_ACCESS',['../libwacom_8h.html#ac3d9ee175999d6b22cee82aae8f829deac75d78a6e9b7623893cf1df578d45621',1,'libwacom.h']]],
  ['werror_5fbad_5falloc',['WERROR_BAD_ALLOC',['../libwacom_8h.html#ac3d9ee175999d6b22cee82aae8f829dea3d78c00cc843776081a65ee1a5aa422c',1,'libwacom.h']]],
  ['werror_5finvalid_5fdb',['WERROR_INVALID_DB',['../libwacom_8h.html#ac3d9ee175999d6b22cee82aae8f829dea6a71f4220569aa8f02a5e1aff0849d3a',1,'libwacom.h']]],
  ['werror_5finvalid_5fpath',['WERROR_INVALID_PATH',['../libwacom_8h.html#ac3d9ee175999d6b22cee82aae8f829deafcbd87b0d3a6cd34d62fb273f0c98948',1,'libwacom.h']]],
  ['werror_5fnone',['WERROR_NONE',['../libwacom_8h.html#ac3d9ee175999d6b22cee82aae8f829dea07a92a6da7f7a6f6da02fac013e2f1d8',1,'libwacom.h']]],
  ['werror_5funknown_5fmodel',['WERROR_UNKNOWN_MODEL',['../libwacom_8h.html#ac3d9ee175999d6b22cee82aae8f829dea5b60ef039615d8c012fa011025177a91',1,'libwacom.h']]],
  ['wfallback_5fgeneric',['WFALLBACK_GENERIC',['../libwacom_8h.html#ac345850b5a595ab24cf120e2a89005d7a1e9f569873e7c61e7998fd99967a11e0',1,'libwacom.h']]],
  ['wfallback_5fnone',['WFALLBACK_NONE',['../libwacom_8h.html#ac345850b5a595ab24cf120e2a89005d7a5b09a66d5f5ae50891993d7cf5d6cd45',1,'libwacom.h']]],
  ['wstylus_5fairbrush',['WSTYLUS_AIRBRUSH',['../libwacom_8h.html#a6f96ee71140aee8ac56c80fb8353c3f6a2b2b5a21b1b32b4655bdd7a2523d1d5f',1,'libwacom.h']]],
  ['wstylus_5fclassic',['WSTYLUS_CLASSIC',['../libwacom_8h.html#a6f96ee71140aee8ac56c80fb8353c3f6a5e7fa448c848fbf5305292d2f37ded4f',1,'libwacom.h']]],
  ['wstylus_5fgeneral',['WSTYLUS_GENERAL',['../libwacom_8h.html#a6f96ee71140aee8ac56c80fb8353c3f6a83751cf86d3119e7ee5575286871da72',1,'libwacom.h']]],
  ['wstylus_5finking',['WSTYLUS_INKING',['../libwacom_8h.html#a6f96ee71140aee8ac56c80fb8353c3f6a69f019a42c8f058f383e9570d07129dc',1,'libwacom.h']]],
  ['wstylus_5fmarker',['WSTYLUS_MARKER',['../libwacom_8h.html#a6f96ee71140aee8ac56c80fb8353c3f6a0b434fba67e0e26359ee96bdbe5e5171',1,'libwacom.h']]],
  ['wstylus_5fpuck',['WSTYLUS_PUCK',['../libwacom_8h.html#a6f96ee71140aee8ac56c80fb8353c3f6aab5835d0572f445f5aaf555315a074d7',1,'libwacom.h']]],
  ['wstylus_5fstroke',['WSTYLUS_STROKE',['../libwacom_8h.html#a6f96ee71140aee8ac56c80fb8353c3f6a99c68bfb134bbbb0a7aee9aab11ebf35',1,'libwacom.h']]],
  ['wstylus_5funknown',['WSTYLUS_UNKNOWN',['../libwacom_8h.html#a6f96ee71140aee8ac56c80fb8353c3f6ab0ce0a738eb1d022736559e59a7b64d6',1,'libwacom.h']]]
];
